colour.models.dataset.xtreme_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.xtreme_rgb Module

## Xtreme RGB Colourspace

Defines the Xtreme RGB colourspace:

- `XTREME_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.hutchcolor.com/profiles/XtremeRGB.zip (Last accessed 12 April 2014)

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_PRIMARIES` = array([[1, 0], [0, 1], [0, 0]])

  Xtreme RGB colourspace primaries.

  XTREME_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_WHITEPOINT` = (0.34567, 0.3585)

  Xtreme RGB colourspace whitepoint.

  XTREME_RGB_WHITEPOINT : tuple

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_TO_XYZ_MATRIX` = array([[ 0.96421199, 0. , 0. ], [ 0. , 1. , 0. ], [ 0. , 0. , 0.82518828]])

  Xtreme RGB colourspace to CIE XYZ colourspace matrix.

  XTREME_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.xtreme_rgb.` `XYZ_TO_XTREME_RGB_MATRIX` = array([[ 1.03711632, 0. , 0. ], [ 0. , 1. , 0. ], [ 0. , 0. , 1.21184464]])

  CIE XYZ colourspace to Xtreme RGB colourspace matrix.

  XYZ_TO_XTREME_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Xtreme RGB colourspace.

  XTREME_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Xtreme RGB colourspace to linear.

  XTREME_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.xtreme_rgb.` `XTREME_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29cd0>

  Xtreme RGB colourspace.

  XTREME_RGB_COLOURSPACE : RGB_Colourspace